=======
Modules
=======

dicomsort
=========

Core
----

.. automodule:: dicomsort.core
    :members:
    :undoc-members:
    :show-inheritance:

mappers
-------

.. automodule:: dicomsort.mappers
    :members:
    :undoc-members:
    :show-inheritance:

parser
------

.. automodule:: dicomsort.parser
    :members:
    :undoc-members:
    :show-inheritance:

folderprocessing
----------------

.. automodule:: dicomsort.folderprocessing
    :members:
    :undoc-members:
    :show-inheritance:

